@@ -187,7 +187,10 @@ class LabelBase(Group):
      This is helpful when two or more labels need to be aligned to the same baseline
     :param (int,str) tab_replacement: tuple with tab character replace information. When
      (4, " ") will indicate a tab replacement of 4 spaces, defaults to 4 spaces by
-     tab character"""
+     tab character
+    :param str label_direction: string defining the label text orientation. There are 5
+     configurations possibles ``LTR``-Left-To-Right ``RTL``-Right-To-Left
+     ``TTB``-Top-To-Bottom ``UPR``-Upwards ``DWR``-Downwards. It defaults to ``LTR``"""
 
     # pylint: disable=unused-argument,  too-many-instance-attributes, too-many-locals, too-many-arguments
     def __init__(
@@ -211,6 +214,7 @@ class LabelBase(Group):
         scale: int = 1,
         base_alignment: bool = False,
         tab_replacement: Tuple[int, str] = (4, " "),
+        label_direction: str = "LTR",
         **kwargs,
     ) -> None:
         super().__init__(max_size=1, x=x, y=y, scale=1)
@@ -230,6 +234,11 @@ class LabelBase(Group):
         self.local_group = None
 
         self._text = text
+
+        if label_direction not in ["LTR", "RTL", "UPR", "DWR", "TTB"]:
+            raise RuntimeError("Please provide a valid text direction")
+        self._label_direction = label_direction
+
         self.baseline = -1.0
 
         self.base_alignment = base_alignment
@@ -388,3 +397,19 @@ class LabelBase(Group):
     @line_spacing.setter
     def line_spacing(self, new_line_spacing: float) -> None:
         self._set_line_spacing(new_line_spacing)
+
+    @property
+    def label_direction(self) -> str:
+        """Set the text direction of the label"""
+        return self._label_direction
+
+    def _set_label_direction(self, new_label_direction: str) -> None:
+        # subclass should override this.
+        pass
+
+    @label_direction.setter
+    def label_direction(self, new_label_direction: str) -> None:
+        """Set the text direction of the label"""
+        if new_label_direction not in ["LTR", "RTL", "UPR", "DWR", "TTB"]:
+            raise RuntimeError("Please provide a valid text direction")
+        self._set_label_direction(new_label_direction)
